==> pyCapsid-0.2.6.tar.gz: pyCapsid-0.2.6/README.md <==
# pyCapsid

## Description
A python package for identification of dominant motions and rigid domains of protein shells using Elastic Network Models.

## Installation
The package requires python >3.6 and < 3.11, we reccommend python 3.10.
Via pip:
~~~~
pip install pyCapsid
~~~~

Via conda: 
~~~~
conda install -c luque_lab -c conda-forge pycapsid
~~~~

## Documentation
Documentation is provided on our github pages site: [https://luquelab.github.io/pyCapsid/](https://luquelab.github.io/pyCapsid/)

## Examples
An example notebook is provided in the [notebooks folder](https://github.com/luquelab/pyCapsid/tree/main/notebooks).
An accompanying tutorial is provided in the documentation.

## Github Repository
The Github Repository of this project: [https://github.com/luquelab/pyCapsid](https://github.com/luquelab/pyCapsid)

## Project History
This is an evolving repository
Started: 2022-10-24


## FILES & FOLDERS
FOLDER: /bin
--> This folder contains basic scripts and executable files.

FOLDER: /data
--> This folder contains the raw data associated with the project and the potential references.

FOLDER: /docs
--> This folder contains the manuscript, digital copies of the cited references, figures, and other associated files for publication.

FOLDER: /results
--> This folder contains the results, performance analysis, and commented references associated with the project.

FOLDER: /src
--> This folder contains source code of the package.

The syntax of markdown files (.md) is CommonMark unless specified otherwise (https://commonmark.org/help/)

==> pyCapsid-0.5.2.tar.gz: pyCapsid-0.5.2/README.md <==
# pyCapsid

## Description
A python package for identification of dominant motions and rigid domains of protein shells using Elastic Network Models.

## Installation
The package requires python >3.7 and < 3.11, we reccommend python 3.10.
Via pip:
~~~~
pip install pyCapsid
~~~~

Via conda: 
~~~~
conda install -c luque_lab -c conda-forge pycapsid
~~~~

## Documentation
Documentation is provided on our github pages site: [https://luquelab.github.io/pyCapsid/](https://luquelab.github.io/pyCapsid/)

## Examples
We recommend using this [Colab notebook](https://colab.research.google.com/github/luquelab/pyCapsid/blob/main/notebooks/pyCapsid_colab_notebook.ipynb)
as the simplest way to use pyCapsid.
Example notebooks are provided in the [notebooks folder](https://github.com/luquelab/pyCapsid/tree/main/notebooks).
An accompanying tutorial is provided in the documentation.

## Github Repository
The Github Repository of this project: [https://github.com/luquelab/pyCapsid](https://github.com/luquelab/pyCapsid)

## Project History
This is an evolving repository
Started: 2022-10-24


## FILES & FOLDERS
FOLDER: /bin
--> This folder contains basic scripts and executable files.

FOLDER: /data
--> This folder contains the raw data associated with the project and the potential references.

FOLDER: /docs
--> This folder contains the manuscript, digital copies of the cited references, figures, and other associated files for publication.

FOLDER: /results
--> This folder contains the results, performance analysis, and commented references associated with the project.

FOLDER: /src
--> This folder contains source code of the package.

The syntax of markdown files (.md) is CommonMark unless specified otherwise (https://commonmark.org/help/)
